A Command Line Interface based FileWriter Function , that takes a user input and writes files. 

open a new file called start.py

from html_writer import create_index_html

create_index_html()

else,
create a new file called run.py and enter the following code and deploy:

//run.py

#!/bin/bash

bash chmod +x run.sh
